@@ -24,7 +24,7 @@
 #define _h_bdf
 
 /*
- * $Id: bdf.h,v 1.17 1998/02/06 21:17:11 mleisher Exp $
+ * $Id: bdf.h,v 1.1 1998/07/24 16:12:17 mleisher Exp $
  */
 
 #include <stdio.h>
@@ -291,6 +291,8 @@ typedef struct {
 
 #define BDF_NOT_CONSOLE_FONT  -10
 #define BDF_NOT_MF_FONT       -11
+#define BDF_NOT_PSF_FONT      -12
+#define BDF_EMPTY_FONT        -99
 #define BDF_INVALID_LINE      -100
 
 typedef struct {
@@ -357,6 +359,9 @@ extern int bdf_load_mf_font __((FILE *in, bdf_options_t *opts,
 extern void bdf_save_font __((FILE *out, bdf_font_t *font,
                               bdf_options_t *opts, bdf_callback_t callback,
                               void *data));
+
+extern int bdf_export_psf __((FILE *out, bdf_font_t *font));
+
 extern void bdf_free_font __((bdf_font_t *font));
 
 #ifdef HAVE_FREETYPE
@@ -439,6 +444,11 @@ extern unsigned long bdf_font_property_list __((bdf_font_t *font,
 extern int bdf_replace_comments __((bdf_font_t *font, char *comments,
                                     unsigned long comments_len));
 
+/*
+ * Other miscellaneous functions.
+ */
+extern void bdf_set_default_metrics __((bdf_font_t *font));
+
 /*
  * Font glyph editing functions.
  */
