@@ -22,9 +22,9 @@
  */
 #ifndef lint
 #ifdef __GNUC__
-static char rcsid[] __attribute__ ((unused)) = "$Id: bdfcons.c,v 1.8 1998/02/06 21:17:11 mleisher Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Id: bdfcons.c,v 1.1 1998/07/24 16:12:18 mleisher Exp $";
 #else
-static char rcsid[] = "$Id: bdfcons.c,v 1.8 1998/02/06 21:17:11 mleisher Exp $";
+static char rcsid[] = "$Id: bdfcons.c,v 1.1 1998/07/24 16:12:18 mleisher Exp $";
 #endif
 #endif
 
@@ -418,7 +418,6 @@ int *awidth;
             initial = 1;
             while (fread((char *) &code, sizeof(unsigned short), 1, in) == 1 &&
                    code != _BDF_PSFSEP) {
-
                 /*
                  * If this is a big-endian machine, make sure the code
                  * point is swapped from little to big endian.
@@ -465,6 +464,16 @@ int *awidth;
                     gp->encoding = (long) code;
                 }
             }
+
+            if (initial) {
+                /*
+                 * The code was the separator, so delete the current bitmap
+                 * and reset the current glyph.
+                 */
+                free((char *) fp->glyphs[i].bitmap);
+                (void) memset((char *) &fp->glyphs[i], 0, sizeof(bdf_glyph_t));
+                fp->glyphs_used--;
+            }
         }
 
         /*
@@ -848,3 +857,108 @@ int *nfonts;
 
     return BDF_OK;
 }
+
+int
+#ifdef __STDC__
+bdf_export_psf(FILE *out, bdf_font_t *font)
+#else
+bdf_export_psf(out, font)
+FILE *out;
+bdf_font_t *font;
+#endif
+{
+    unsigned short enc[2];
+    char *blank;
+    long i, le, top;
+    bdf_glyph_t *gp;
+    psfhdr_t hdr;
+
+    if (font->glyphs_used == 0)
+      return BDF_EMPTY_FONT;
+
+    /*
+     * If the width is larger than 8 or it is not a character cell font,
+     * then the font cannot be saved as PSF.
+     */
+    if (font->bbx.width > 8 || font->spacing != BDF_CHARCELL)
+      return BDF_NOT_PSF_FONT;
+
+    /*
+     * Set the little endian PSF identifier.
+     */
+    hdr.mag = (!bdf_little_endian()) ? 0x3604 : 0x0436;
+
+    /*
+     * Initialize the flags and height.
+     */
+    hdr.mode = (font->glyphs_used <= 256) ? _BDF_PSF256 : _BDF_PSF512;
+    hdr.height = font->bbx.height;
+
+    top = (hdr.mode & _BDF_PSF512) ? 512 : 256;
+
+    /*
+     * Allocate a blank bitmap for the empties.
+     */
+    blank = (char *) malloc(hdr.height);
+    (void) memset(blank, 0, hdr.height);
+
+    /*
+     * Write the header.
+     */
+    fwrite((char *) &hdr, sizeof(psfhdr_t), 1, out);
+
+    /*
+     * Generate the glyphs.
+     */
+    for (le = _BDF_PSFSEP, i = 0, gp = font->glyphs; i < top; i++) {
+        if (i >= font->glyphs_used)
+          /*
+           * Write out the blank bitmap.
+           */
+          fwrite(blank, sizeof(unsigned char), hdr.height, out);
+        else {
+            /*
+             * If the encoding of the current glyph is greater than the last
+             * glyph plus one, then a mapping table needs to be written after
+             * the glyphs.
+             */
+            if (!(hdr.mode & _BDF_PSFMAP) && gp->encoding > le + 1)
+              hdr.mode |= _BDF_PSFMAP;
+            fwrite((char *) gp->bitmap, sizeof(unsigned char), hdr.height,
+                   out);
+            le = gp->encoding;
+            gp++;
+        }
+    }
+
+    /*
+     * If a mapping table must be written, write it out and then rewrite the
+     * header to include the flag.
+     */
+    if (hdr.mode & _BDF_PSFMAP) {
+        enc[1] = _BDF_PSFSEP;
+        for (i = 0, gp = font->glyphs; i < top; i++) {
+            if (i >= font->glyphs_used) {
+                enc[0] = _BDF_PSFSEP;
+                fwrite((char *) enc, sizeof(unsigned short), 1, out);
+            } else {
+                /*
+                 * Make sure the encoding is in little endian order.
+                 */
+                enc[0] = (bdf_little_endian()) ? gp->encoding :
+                    ((gp->encoding & 0xff) << 8) |
+                    ((gp->encoding >> 8) & 0xff);
+                fwrite((char *) enc, sizeof(unsigned short), 2, out);
+                gp++;
+            }
+        }
+
+        /*
+         * Return to the beginning of the file and rewrite the header.
+         */
+        fseek(out, 0, 0L);
+        fwrite((char *) &hdr, sizeof(psfhdr_t), 1, out);
+    }
+
+    return BDF_OK;
+}
