@@ -28,9 +28,9 @@
 
 #ifndef lint
 #ifdef __GNUC__
-static char rcsid[] __attribute__ ((unused)) = "$Id: bdfttf.c,v 1.5 1998/02/06 21:17:11 mleisher Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Id: bdfttf.c,v 1.1 1998/07/24 16:12:22 mleisher Exp $";
 #else
-static char rcsid[] = "$Id: bdfttf.c,v 1.5 1998/02/06 21:17:11 mleisher Exp $";
+static char rcsid[] = "$Id: bdfttf.c,v 1.1 1998/07/24 16:12:22 mleisher Exp $";
 #endif
 #endif
 
@@ -85,7 +85,7 @@ static int niso_encodings = sizeof(iso_encodings) / sizeof(iso_encodings[0]);
  * when selecting an encoding from a font.
  */
 static char *ms_encodings[] = {
-    "Symbol", "Unicode", "ShiftJIS", "GB2312.1980", "Big5",
+    "Symbol", "ISO10646", "ShiftJIS", "GB2312.1980", "Big5",
     "KSC5601.1987", "KSC5601.1992"
 };
 static int nms_encodings = sizeof(ms_encodings) / sizeof(ms_encodings[0]);
@@ -126,7 +126,7 @@ short pid, eid;
     char **names;
 
     switch (pid) {
-      case 0: return "Unicode";
+      case 0: return "ISO10646";
       case 1:
         nnames = nmac_encodings;
         names = mac_encodings;
@@ -171,9 +171,10 @@ int nameID, dash_to_space;
 char *name;
 #endif
 {
-    int i, j, encid, slen, nrec;
+    int i, j, encid, nrec;
     short nrPlatformID, nrEncodingID, nrLanguageID, nrNameID;
     char *s;
+    unsigned short slen;
 
     nrec = TT_Get_Name_Count(face);
 
@@ -348,8 +349,7 @@ bdf_font_t *fp;
     raster.size = raster.cols * raster.rows;
     raster.bitmap = (void *) malloc(raster.size);
 
-    for (code = fp->glyphs_used = 0;
-         fp->glyphs_used < properties->num_Glyphs && code < 0xffff; code++) {
+    for (code = fp->glyphs_used = 0; code < 0xffff; code++) {
         if (nocmap) {
             /*
              * No cmap is being used, so do each index in turn.
@@ -748,14 +748,14 @@ bdf_font_t **font;
             prop.format = BDF_ATOM;
             prop.value.atom = "1";
             bdf_add_font_property(fp, &prop);
-        } else if (strcmp(np, "Unicode") == 0) {
+        } else if (strcmp(np, "ISO10646") == 0) {
             prop.name = "CHARSET_REGISTRY";
             prop.format = BDF_ATOM;
             prop.value.atom = np;
             bdf_add_font_property(fp, &prop);
             prop.name = "CHARSET_ENCODING";
             prop.format = BDF_ATOM;
-            prop.value.atom = "2.0";
+            prop.value.atom = "1";
             bdf_add_font_property(fp, &prop);
         } else {
             prop.name = "CHARSET_REGISTRY";
