@@ -22,9 +22,9 @@
  */
 #ifndef lint
 #ifdef __GNUC__
-static char rcsid[] __attribute__ ((unused)) = "$Id: finfo.c,v 1.3 1998/02/06 21:17:11 mleisher Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Id: finfo.c,v 1.1 1998/07/24 16:12:23 mleisher Exp $";
 #else
-static char rcsid[] = "$Id: finfo.c,v 1.3 1998/02/06 21:17:11 mleisher Exp $";
+static char rcsid[] = "$Id: finfo.c,v 1.1 1998/07/24 16:12:23 mleisher Exp $";
 #endif
 #endif
 
@@ -199,6 +199,35 @@ MXFEditor *ed;
     XtSetArg(av[ac], XmNtopAttachment, XmATTACH_FORM); ac++;
     XtSetArg(av[ac], XmNleftAttachment, XmATTACH_FORM); ac++;
     XtSetArg(av[ac], XmNrightAttachment, XmATTACH_FORM); ac++;
+    sprintf(name, "xmbdfed_fontinfo%ld_gcount_frame", ed->id);
+    frame = XtCreateManagedWidget(name, xmFrameWidgetClass, form, av, ac);
+
+    ac = 0;
+    XtSetArg(av[ac], XmNchildType, XmFRAME_TITLE_CHILD); ac++;
+    label = XtCreateManagedWidget("Font Glyph Counts", xmLabelWidgetClass,
+                                  frame, av, ac);
+
+    ac = 0;
+    XtSetArg(av[ac], XmNorientation, XmHORIZONTAL); ac++;
+    XtSetArg(av[ac], XmNpacking, XmPACK_COLUMN); ac++;
+    XtSetArg(av[ac], XmNnumColumns, 1); ac++;
+    sprintf(name, "xmbdfed_fontinfo%ld_gcount_rowcol", ed->id);
+    rc = XtCreateManagedWidget(name, xmRowColumnWidgetClass, frame, av, ac);
+
+    label = XtCreateManagedWidget("Encoded:", xmLabelWidgetClass, rc,
+                                  0, 0);
+    ed->finfo.enc = XtCreateManagedWidget("00", xmLabelWidgetClass, rc,
+                                          0, 0);
+    label = XtCreateManagedWidget("Unencoded:", xmLabelWidgetClass, rc,
+                                  0, 0);
+    ed->finfo.unenc = XtCreateManagedWidget("00", xmLabelWidgetClass, rc,
+                                            0, 0);
+
+    ac = 0;
+    XtSetArg(av[ac], XmNtopAttachment, XmATTACH_WIDGET); ac++;
+    XtSetArg(av[ac], XmNtopWidget, frame); ac++;
+    XtSetArg(av[ac], XmNleftAttachment, XmATTACH_FORM); ac++;
+    XtSetArg(av[ac], XmNrightAttachment, XmATTACH_FORM); ac++;
     sprintf(name, "xmbdfed_fontinfo%ld_defchar_frame", ed->id);
     frame = XtCreateManagedWidget(name, xmFrameWidgetClass, form, av, ac);
 
@@ -240,8 +269,7 @@ MXFEditor *ed;
 
     ac = 0;
     XtSetArg(av[ac], XmNorientation, XmHORIZONTAL); ac++;
-    XtSetArg(av[ac], XmNpacking, XmPACK_COLUMN); ac++;
-    XtSetArg(av[ac], XmNnumColumns, 3); ac++;
+    XtSetArg(av[ac], XmNnumColumns, 1); ac++;
     XtSetArg(av[ac], XmNisAligned, True); ac++;
     XtSetArg(av[ac], XmNentryAlignment, XmALIGNMENT_END); ac++;
     sprintf(name, "xmbdfed_fontinfo%ld_metrics_rowcol", ed->id);
@@ -292,8 +320,7 @@ MXFEditor *ed;
 
     ac = 0;
     XtSetArg(av[ac], XmNorientation, XmHORIZONTAL); ac++;
-    XtSetArg(av[ac], XmNpacking, XmPACK_COLUMN); ac++;
-    XtSetArg(av[ac], XmNnumColumns, 2); ac++;
+    XtSetArg(av[ac], XmNnumColumns, 1); ac++;
     XtSetArg(av[ac], XmNisAligned, True); ac++;
     XtSetArg(av[ac], XmNentryAlignment, XmALIGNMENT_END); ac++;
     sprintf(name, "xmbdfed_fontinfo%ld_resolution_rowcol", ed->id);
@@ -406,15 +433,37 @@ XtPointer client_data, call_data;
 #endif
 {
     MXFEditor *ed;
+    XmString s;
     Arg av[1];
     char nbuf[25];
     XmuttFontGridFontInfoStruct info;
+    XmuttFontGridPageInfoStruct pinfo;
 
     ed = &editors[(unsigned long) client_data];
 
     if (ed->finfo.shell == 0)
       BuildFontInfo(ed);
 
+    /*
+     * Get the page info from the grid.
+     */
+    XmuttFontGridPageInfo(ed->fgrid, &pinfo);
+
+    /*
+     * Set the encoded and unencoded glyphs counts.
+     */
+    sprintf(nbuf, "%ld", pinfo.num_encoded);
+    s = XmStringCreateSimple(nbuf);
+    XtSetArg(av[0], XmNlabelString, s);
+    XtSetValues(ed->finfo.enc, av, 1);
+    XmStringFree(s);
+
+    sprintf(nbuf, "%ld", pinfo.num_unencoded);
+    s = XmStringCreateSimple(nbuf);
+    XtSetArg(av[0], XmNlabelString, s);
+    XtSetValues(ed->finfo.unenc, av, 1);
+    XmStringFree(s);
+
     /*
      * Get the font info from the grid.
      */
