@@ -22,9 +22,9 @@
  */
 #ifndef lint
 #ifdef __GNUC__
-static char rcsid[] __attribute__ ((unused)) = "$Id: glyphed.c,v 1.15 1998/02/06 21:17:11 mleisher Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Id: glyphed.c,v 1.3 1998/10/12 18:46:43 mleisher Exp $";
 #else
-static char rcsid[] = "$Id: glyphed.c,v 1.15 1998/02/06 21:17:11 mleisher Exp $";
+static char rcsid[] = "$Id: glyphed.c,v 1.3 1998/10/12 18:46:43 mleisher Exp $";
 #endif
 #endif
 
@@ -225,6 +225,8 @@ XtPointer client_data, call_data;
      */
     XmuttGlyphEditSetModified(ge->gedit, False);
     XtSetSensitive(ge->update, False);
+    XtSetSensitive(ge->update_next, False);
+    XtSetSensitive(ge->update_prev, False);
 }
 
 static void
@@ -457,6 +459,12 @@ XtPointer client_data, call_data;
 
     ge = &glyph_editors[(unsigned long) client_data];
 
+    /*
+     * Simply return if it has already been popped down.
+     */
+    if (ge->owner == ~0)
+      return;
+
     /*
      * Check to see if the glyph has been modified or not and ask if it should
      * be updated.
@@ -928,6 +936,7 @@ XtPointer client_data, call_data;
     sprintf(name, "%hd", grid->dwidth);
     XtSetSensitive(ge->dwidth, True);
     XmTextFieldSetString(ge->dwidth, name);
+    XmTextSetCursorPosition(ge->dwidth, 4);
     if (grid->spacing != BDF_PROPORTIONAL)
       XtSetSensitive(ge->dwidth, False);
 
@@ -957,10 +966,15 @@ XtPointer client_data, call_data;
     /*
      * Change the sensitivity of the update menu item.
      */
-    if (grid->modified)
-      XtSetSensitive(ge->update, True);
-    else
-      XtSetSensitive(ge->update, False);
+    if (grid->modified) {
+        XtSetSensitive(ge->update, True);
+        XtSetSensitive(ge->update_next, True);
+        XtSetSensitive(ge->update_prev, True);
+    } else {
+        XtSetSensitive(ge->update, False);
+        XtSetSensitive(ge->update_next, False);
+        XtSetSensitive(ge->update_prev, False);
+    }
 }
 
 static void
@@ -1030,6 +1044,7 @@ XtPointer client_data, call_data;
     sprintf(name, "%hd", grid->dwidth);
     XtSetSensitive(ge->dwidth, True);
     XmTextFieldSetString(ge->dwidth, name);
+    XmTextFieldSetCursorPosition(ge->dwidth, 4);
     if (grid->spacing != BDF_PROPORTIONAL)
       XtSetSensitive(ge->dwidth, False);
 
@@ -1059,10 +1074,41 @@ XtPointer client_data, call_data;
     /*
      * Change the sensitivity of the update menu item.
      */
-    if (grid->modified)
-      XtSetSensitive(ge->update, True);
-    else
-      XtSetSensitive(ge->update, False);
+    if (grid->modified) {
+        XtSetSensitive(ge->update, True);
+        XtSetSensitive(ge->update_next, True);
+        XtSetSensitive(ge->update_prev, True);
+    } else {
+        XtSetSensitive(ge->update, False);
+        XtSetSensitive(ge->update_next, False);
+        XtSetSensitive(ge->update_prev, False);
+    }
+}
+
+static void
+#ifndef _NO_PROTO
+DoFontUpdateAndNext(Widget w, XtPointer client_data, XtPointer call_data)
+#else
+DoFontUpdateAndNext(w, client_data, call_data)
+Widget w;
+XtPointer client_data, call_data;
+#endif
+{
+    DoFontUpdate(w, client_data, call_data);
+    DoNextGlyph(w, client_data, call_data);
+}
+
+static void
+#ifndef _NO_PROTO
+DoFontUpdateAndPrev(Widget w, XtPointer client_data, XtPointer call_data)
+#else
+DoFontUpdateAndPrev(w, client_data, call_data)
+Widget w;
+XtPointer client_data, call_data;
+#endif
+{
+    DoFontUpdate(w, client_data, call_data);
+    DoPrevGlyph(w, client_data, call_data);
 }
 
 static void
@@ -1143,6 +1189,8 @@ XtPointer client_data, call_data;
 
     ge = &glyph_editors[(unsigned long) client_data];
     XtSetSensitive(ge->update, True);
+    XtSetSensitive(ge->update_next, True);
+    XtSetSensitive(ge->update_prev, True);
 }
 
 static void
@@ -1174,9 +1222,12 @@ XtPointer client_data, call_data;
     if (cb->metrics->font_spacing == BDF_PROPORTIONAL) {
         sprintf(nbuf, "%hd", cb->metrics->dwidth);
         XmTextFieldSetString(ge->dwidth, nbuf);
+        XmTextFieldSetCursorPosition(ge->dwidth, 4);
     }
 
     XtSetSensitive(ge->update, True);
+    XtSetSensitive(ge->update_next, True);
+    XtSetSensitive(ge->update_prev, True);
 }
 
 static void
@@ -1243,6 +1294,7 @@ XtPointer client_data, call_data;
     sprintf(name, "%hd", grid->dwidth);
     XtSetSensitive(ge->dwidth, True);
     XmTextFieldSetString(ge->dwidth, name);
+    XmTextFieldSetCursorPosition(ge->dwidth, 4);
     if (grid->spacing != BDF_PROPORTIONAL)
       XtSetSensitive(ge->dwidth, False);
 
@@ -1257,10 +1309,15 @@ XtPointer client_data, call_data;
     /*
      * Change the sensitivity of the update menu option.
      */
-    if (grid->modified)
-      XtSetSensitive(ge->update, True);
-    else
-      XtSetSensitive(ge->update, False);
+    if (grid->modified) {
+        XtSetSensitive(ge->update, True);
+        XtSetSensitive(ge->update_next, True);
+        XtSetSensitive(ge->update_prev, True);
+    } else {
+        XtSetSensitive(ge->update, False);
+        XtSetSensitive(ge->update_next, False);
+        XtSetSensitive(ge->update_prev, False);
+    }
 }
 
 static void
@@ -1550,6 +1607,32 @@ MXFEditorGlyphEdit *ge;
     XtAddCallback(ge->update, XmNactivateCallback, DoFontUpdate,
                   (XtPointer) ge->id);
 
+    s = XmStringCreateSimple("Ctrl+U");
+    ac = 0;
+    XtSetArg(av[ac], XmNmnemonic, 'N'); ac++;
+    XtSetArg(av[ac], XmNaccelerator, "Ctrl<Key>u"); ac++;
+    XtSetArg(av[ac], XmNacceleratorText, s); ac++;
+    XtSetArg(av[ac], XmNsensitive, False); ac++;
+    ge->update_next = XtCreateManagedWidget("Update and Next",
+                                            xmPushButtonWidgetClass,
+                                            pdown, av, ac);
+    XmStringFree(s);
+    XtAddCallback(ge->update_next, XmNactivateCallback, DoFontUpdateAndNext,
+                  (XtPointer) ge->id);
+
+    s = XmStringCreateSimple("Ctrl+B");
+    ac = 0;
+    XtSetArg(av[ac], XmNmnemonic, 'P'); ac++;
+    XtSetArg(av[ac], XmNaccelerator, "Ctrl<Key>b"); ac++;
+    XtSetArg(av[ac], XmNacceleratorText, s); ac++;
+    XtSetArg(av[ac], XmNsensitive, False); ac++;
+    ge->update_prev = XtCreateManagedWidget("Update and Previous",
+                                            xmPushButtonWidgetClass,
+                                            pdown, av, ac);
+    XmStringFree(s);
+    XtAddCallback(ge->update_prev, XmNactivateCallback, DoFontUpdateAndPrev,
+                  (XtPointer) ge->id);
+
     sprintf(name, "xmbdfed_glyphedit%ld_file_menu_sep1", ge->id);
     sep = XtCreateManagedWidget(name, xmSeparatorWidgetClass, pdown, 0, 0);
 
@@ -1794,10 +1877,8 @@ MXFEditor *ed;
     sprintf(name, "xmbdfed_glyphedit%ld", ge->id);
     ge->shell = XtCreatePopupShell(name, topLevelShellWidgetClass, top,
                                    av, ac);
-#if 0
-    XtAddCallback(ge->shell, XmNpopupCallback, DoInitialPosition,
+    XtAddCallback(ge->shell, XmNpopdownCallback, DoCloseGlyphEditor,
                   (XtPointer) ge->id);
-#endif
 
     /*
      * Create the main window.
@@ -1945,6 +2026,7 @@ MXFEditor *ed;
      */
     sprintf(name, "%hd", grid->dwidth);
     XmTextFieldSetString(ge->dwidth, name);
+    XmTextFieldSetCursorPosition(ge->dwidth, 4);
     if (grid->spacing != BDF_PROPORTIONAL)
       XtSetSensitive(ge->dwidth, False);
 
@@ -2184,6 +2266,7 @@ XtPointer client_data, call_data;
         sprintf(name, "%hd", grid->dwidth);
         XtSetSensitive(ge->dwidth, True);
         XmTextFieldSetString(ge->dwidth, name);
+        XmTextFieldSetCursorPosition(ge->dwidth, 4);
         if (grid->spacing != BDF_PROPORTIONAL)
           XtSetSensitive(ge->dwidth, False);
 
@@ -2199,10 +2282,15 @@ XtPointer client_data, call_data;
     /*
      * Change the sensitivity of the update menu item.
      */
-    if (grid->modified)
-      XtSetSensitive(ge->update, True);
-    else
-      XtSetSensitive(ge->update, False);
+    if (grid->modified) {
+        XtSetSensitive(ge->update, True);
+        XtSetSensitive(ge->update_next, True);
+        XtSetSensitive(ge->update_prev, True);
+    } else {
+        XtSetSensitive(ge->update, False);
+        XtSetSensitive(ge->update_next, False);
+        XtSetSensitive(ge->update_prev, False);
+    }
 
     /*
      * Pop the editor up.
