@@ -22,12 +22,12 @@
  */
 
 /*
- * $Id: htext.h,v 1.26 1998/02/06 21:17:11 mleisher Exp $
+ * $Id: htext.h,v 1.3 1998/10/12 18:46:43 mleisher Exp $
  */
 static char *about_text = "\
-                 XmBDFEditor 3.0\n\
+                 XmBDFEditor 3.3\n\
               mleisher@crl.nmsu.edu\n\
-                       06 February 1998\n\
+                       12 October 1998\n\
 \n\
 XmBDFEditor is a BDF font editor that supports\n\
 these main features:\n\
@@ -173,6 +173,17 @@ File\n\
 \n\
     Server Font <Ctrl+G>\n\
       This will import a font from the X server.\n\
+\n\
+  Export PSF <Ctrl+F>\n\
+    This will export the current BDF font to a PSF font\n\
+    if the BDF font is less than 8 pixels wide and is a\n\
+    character cell font.\n\
+\n\
+    Only the first 512 or 256 glyphs will be exported\n\
+    depending on how many glyphs are in the font.  A\n\
+    mapping table will be appended to the end of the\n\
+    font if there is any break in the encodings of the\n\
+    glyphs.\n\
 \n\
   Exit/Close <Ctrl+F4>\n\
     Exit the program if this is the primary Font\n\
@@ -404,6 +415,14 @@ File\n\
   Update <Ctrl+S>\n\
     This will update the Font Grid with the\n\
     modified glyph.\n\
+\n\
+  Update and Next <Ctrl+U>\n\
+    This will update the FontGrid with the\n\
+    modified glyph and move to the next glyph.\n\
+\n\
+  Update and Previous <Ctrl+B>\n\
+    This will update the FontGrid with the\n\
+    modified glyph and move to the previous glyph.\n\
 \n\
   Import XBM <Ctrl+I>\n\
     This will pop up a file selection dialog\n\
@@ -843,3 +862,18 @@ a list of fonts to choose from.  You can select as many\n\
 of them as you wish or simply import them all using\n\
 the \"Import All\" button.\n\
 ";
+
+static char *psf_text ="\
+When a PSF font is imported, it can map single glyphs\n\
+to multiple locations with a mapping table following\n\
+the glyphs.  This can cause a font to have more than\n\
+256 glyphs when it is imported, even if it only had\n\
+256 to begin with.  This means that when the font is\n\
+exported as PSF, it will be padded with blank glyphs\n\
+when necessary and will have appropriate separated\n\
+entries in the mapping table if one is generated.\n\
+\n\
+Because of this behavior, PSF fonts exported from\n\
+xmbdfed might not have the same size as the original\n\
+font.\n\
+";
